import { View, Canvas } from '@tarojs/components'
import Taro from '@tarojs/taro'
import { useCallback, useEffect, useMemo, useRef, useState } from 'react'
import S from '@/utils/shape-shifter'

import './style.less'

const ShakeCount = (props) => {
  const { className, value } = props
  const classNames = useMemo(() => [className, 'canvas-counter'].filter(Boolean).join(' '), [className])

  const canvasId = useMemo(() => `f-${Math.random().toString(36).substring(2)}`, [])
  const canvasRef = useRef()
  const canvasShapeRef = useRef()
  const isReady = useRef(false)

  const initS = useCallback(() => {
    if (canvasRef.current && canvasShapeRef.current) {

      S.init({
        canvas: canvasRef.current,
        shape: canvasShapeRef.current,
        width: canvasRef.current.width,
        height: canvasRef.current.height
      })

      isReady.current = true
    }
  }, [])

  useEffect(() => {
    if (isReady.current) {
      S.performAction(value)
    }
  }, [value])

  useEffect(() => {
    Taro.nextTick(() => {
      Taro.createSelectorQuery()
        .select(`#${canvasId}`)
        .fields({ node: true, size: true })
        .exec((res) => {
          const canvas = res[0].node
          const ctx = canvas.getContext('2d')

          const dpr = Taro.getSystemInfoSync().pixelRatio
          const width = res[0].width * dpr
          const height = res[0].height * dpr
          canvas.width = width
          canvas.height = height
          ctx.scale(dpr, dpr)
          
          canvasRef.current = canvas
          initS()
        })

      Taro.createSelectorQuery()
        .select(`#${canvasId}-canvas-shape`)
        .fields({ node: true, size: true })
        .exec((res) => {
          const canvas = res[0].node
          const ctx = canvas.getContext('2d')

          const dpr = Taro.getSystemInfoSync().pixelRatio
          const width = res[0].width * dpr
          const height = res[0].height * dpr
          canvas.width = width
          canvas.height = height
          ctx.scale(dpr, dpr)
          
          canvasShapeRef.current = canvas
          initS()
        })
    })
  }, [canvasId, initS])

  return (
    <View className={classNames}>
      <Canvas id={`${canvasId}-canvas-shape`} className='canvas-shape' type='2d'></Canvas>
      <Canvas id={canvasId} type='2d'></Canvas>
    </View>
  )
}

export default ShakeCount;
