import { View, Canvas } from '@tarojs/components'
import Taro, { useDidHide, useDidShow } from '@tarojs/taro'
import { useCallback, useEffect, useMemo, useRef, useState } from 'react'
import Counter from '@/components/Counter'
import { throttle } from '@/utils'
import newShake from '@/utils/shake'
import S from '@/utils/shape-shifter'

import './style.less'

const { onShake } = newShake()

const ShakeCount = (props) => {
  const { className, onTimes } = props
  const classNames = useMemo(() => [className, 'shake-count'].filter(Boolean).join(' '), [className])

  const [times, setTimes] = useState(0)
  const timesRef = useRef(times)

  // eslint-disable-next-line react-hooks/exhaustive-deps
  const handleShake = useCallback(throttle((times) => {
    setTimes(times)

    if (onTimes) {
      onTimes(times)
    }
  }, 500, { trailing: true, immediate: true }), [])

  useDidShow(() => {
    Taro.startAccelerometer()

    Taro.onAccelerometerChange((e) => {
      onShake(e, () => {
        timesRef.current += 1
        console.log('---times: ', timesRef.current)
        handleShake(timesRef.current)
        // S.performAction(timesRef.current)
      })
    })
  })

  useDidHide(() => {
    Taro.startAccelerometer()
  })

  return (
    <View className={classNames}>
      <Counter value={times} />
    </View>
  )
}

export default ShakeCount;
